import typer
import uvicorn
from kalibr.kalibr_sdk import app

cli = typer.Typer(help="Kalibr SDK CLI")

@cli.command()
def serve(host: str = "0.0.0.0", port: int = 8000):
    """
    Start the Kalibr API server.
    """
    uvicorn.run(app, host=host, port=port, reload=False)

def main():
    cli()

if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

setup(
    name="kalibr",
    version="0.1.21",
    description="Kalibr Demo SDK",
    author="Devon Kelley",
    packages=find_packages(),
    install_requires=[
        "fastapi",
        "uvicorn",
        "typer",   # CLI framework
    ],
    entry_points={
        "console_scripts": [
            "kalibr=kalibr.__main__:main",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
)
